Tüm Ürünler
Search
Belge Merkezi

Cloud Parallel File Storage:Alibaba Cloud Linux üzerinde CPFS-POSIX istemcisi kullanarak bir CPFS dosya sistemi bağlayın

Son Güncelleme:Oct 07, 2026

Alibaba Cloud Linux 2 üzerine bir CPFS-POSIX istemcisi yükleyin ve bu istemciyi kullanarak bir CPFS dosya sistemi bağlayın.

Arka Plan

  • Bu konuda bahsedilen hedef ECS örnekleri, CPFS dosya sistemini bağlayan ve erişen hesaplama düğümleridir.

  • Cloud Parallel File Storage (CPFS), POSIX arayüzü ile uyumludur. Bir CPFS-POSIX istemcisi yükleyip dosya sistemi bağlayarak CPFS'yi kullanabilirsiniz. CPFS-POSIX istemcisi özelleştirilmiş hizmetler sunar ve Alibaba Cloud Linux 2 üzerinde kurulumu destekler. CPFS dosya sistemine NFS protokolü üzerinden erişmek istiyorsanız Bir dosya sistemini CPFS-NFS istemcisi kullanarak bağlama konusuna bakın.

  • Bir POSIX bağlama noktası ekledikten sonra CPFS otomatik olarak üç yönetim düğümü ECS örneği oluşturur: <FSID>-<GENID>-qr-001, <FSID>-<GENID>-qr-002 ve <FSID>-<GENID>-qr-003. Listedeki ilk yönetim düğümü ECS örneği (<FSID>-<GENID>-qr-001), varsayılan CPFS-POSIX istemci kurulum düğümüdür.

Ön Koşullar

  • Bir dosya sistemi oluşturulmuş olmalıdır. Daha fazla bilgi için Dosya sistemi oluşturma konusuna bakın.

  • Bir POSIX bağlama noktası eklenmiş olmalıdır. Daha fazla bilgi için POSIX bağlama hedefi ekleme konusuna bakın.

  • Bir veya daha fazla Alibaba Cloud Linux 2 ECS örneği oluşturulmuş olmalı ve örnek teknik özellikleri aşağıdaki gibi olmalıdır.

    • Sürüm: Alibaba Cloud Linux 2.1903 LTS 64-bit

    • Çekirdek sürümü: 4.19.91-27.4.al7.x86_64 veya daha eski bir sürüm.

      Çekirdek sürümünü kontrol etmek için uname -r komutunu çalıştırabilirsiniz.

Adım 1: Hedef ECS örnekleri için güvenlik grubunu yapılandırma

Ön koşullarda oluşturulan ECS örneklerine bir dosya sistemi bağlamadan önce, CPFS-POSIX yönetim düğümü ECS örneklerinin güvenlik grubunu hedef ECS örneklerine eklemeniz gerekir. Bu işlem, hedef ECS örnekleri ile CPFS kümesi arasındaki uzaktan bağlantı ve veri iletiminde yaşanabilecek başarısızlıkları önler.

  1. CPFS-POSIX kontrol düğümünün güvenlik grubu kimliğini edinin.

    1. NAS konsolu üzerinde oturum açın.

    2. Sol gezinme bölmesinde File Systems > File System List seçeneğini belirleyin.

    3. Sayfanın sol üst köşesinde hedef dosya sisteminin kaynak grubunu ve bölgesini seçin.

      image

    4. Hedef dosya sistemine tıklayın. Ayrıntılar sayfasında Mount Targets sekmesine tıklayın.

    5. Client Management node bölümünde, listedeki ilk ECS örneğine tıklayarak örnek ayrıntıları sayfasına gidin.

    6. Instance Details sayfasında Security Groups sekmesine tıklayın ve kontrol düğümünün Security Group ID/Name değerini not edin.

      Kontrol düğümünün güvenlik grubu adı şu biçimi izler: <FSID>-<GENID>-qr-sg.

      Bu biçimde <FSID>, CPFS dosya sistemi kimliğidir ve <GENID>, her bir CPFS bağlama hedefi oluşturulduğunda artan bağlama hedefi sıra numarasıdır.

  2. Kontrol düğümünün güvenlik grubunu hedef ECS örneğine ekleyin.

    1. Sol gezinme bölmesinde Instances & Images > Instances seçeneğini belirleyin.

    2. Instance List sayfasında bağlanacak ECS örneği kimliğine tıklayın, Security Groups sekmesini seçin ve Change Security Group öğesine tıklayın.

    3. Change Security Group iletişim kutusunda Security Groups açılır listesinden Adım 1 içinde kaydedilen kontrol düğümü güvenlik grubunu (<FSID>-<GENID>-qr-sg) seçin ve OK öğesine tıklayın.

Adım 2: CPFS-POSIX istemcisi yükleme

  1. NAS konsolu üzerinde oturum açın.

  2. Sol gezinme bölmesinde File System > File System List seçeneğini belirleyin.

  3. Sayfanın sol üst köşesinde hedef dosya sisteminin bulunduğu kaynak grubunu ve bölgeyi seçin.

    Kaynak grupları arasında geçiş yapmak için üst gezinme çubuğundaki All Resources açılır listesini kullanın.

  4. Dosya sistemi ayrıntıları sayfasına gitmek için hedef dosya sistemine tıklayın ve Mount Targets öğesine tıklayın.

  5. Client Management node bölümünde, listedeki ilk yönetim düğümü ECS örneğine tıklayarak örneğin ayrıntılar sayfasına gidin.

  6. CPFS-POSIX istemci kurulum düğümünde oturum açmak için Connect öğesine tıklayın.

  7. Yönetim düğümü ile hedef ECS örnekleri arasında parola gerektirmeyen oturum açmayı yapılandırın.

    Not

    CPFS yönetim düğümleri ile birden fazla ECS örneği arasında parola gerektirmeyen oturum açmayı yapılandırmadan önce hedef ECS örneklerinin oturum açma parolalarını aynı parola olarak ayarlamanızı öneririz. Aksi takdirde client.list dosyasını birden çok kez oluşturmanız ve 10. ile 12. adımları tekrar etmeniz gerekir.

    1. client.list dosyasını oluşturun ve hedef ECS örneklerinin özel IP adreslerini ekleyin.

      1. client.list dosyasını oluşturun

        touch client.list
      2. vi client.list komutunu çalıştırarak client.list dosyasını açın ve hedef ECS örneklerinin özel IP adreslerini ekleyin.

        <Private IP address of target ECS instance 1> 
        <Private IP address of target ECS instance 2>
        <Private IP address of target ECS instance 3>

        Örnek:

        192.168.1.249
        192.168.1.250
        192.168.1.251
        Not

        Bir veya daha fazla ECS örneği ekleyebilirsiniz. Birden fazla ECS örneği eklerken hedef ECS örneklerinin özel IP adreslerini ayrı satırlara girin.

      3. Kaydedin ve çıkış yapın.

    2. qr.list dosyasını oluşturun ve yönetim düğümü IP adreslerini ekleyin.

      1. qr.list dosyasını oluşturun

        touch qr.list
      2. vi qr.list komutunu çalıştırarak qr.list dosyasını açın ve yönetim düğümü IP adreslerini ekleyin. Aşağıdaki örnek içeriği göstermektedir:

        10.0.2.41
        10.0.2.42
        10.0.2.43

        Client Management node bölümü, CPFS-POSIX istemci yönetim düğümlerinin IP adreslerini listeler.

      3. Kaydedin ve çıkış yapın.

    3. auto_ssh.sh betiğini yapılandırın.

      1. auto_ssh.sh dosyasını oluşturun.

        touch auto_ssh.sh
      2. vi auto_ssh.sh komutunu çalıştırarak auto_ssh.sh dosyasını açın ve aşağıdaki içeriği ekleyin.

        #!/usr/bin/expect
        set timeout 10
        set username [lindex $argv 0]
        set password [lindex $argv 1]
        set hostname [lindex $argv 2]
        spawn ssh-copy-id -i /root/.ssh/id_rsa.pub $username@$hostname
        expect {
            #first connect, no public key in ~/.ssh/known_hosts
            "Are you sure you want to continue connecting (yes/no)?" {
                send "yes\r"
                expect "password:"
                send "$password\r"
            }
            #already has public key in ~/.ssh/known_hosts
            "password:" {
                send "$password\r"
            }
            "Now try logging into the machine" {
                #it has authorized, do nothing!
            }
            "already exist on the remote" {
                #it has authorized, do nothing!
            }
        }
        expect eof
        
      3. Kaydedin ve çıkış yapın.

  8. Kullanıcıya auto_ssh.sh dosyası üzerinde yürütme izni vermek için aşağıdaki komutu çalıştırın.

    chmod +x auto_ssh.sh
  9. client.list içindeki hedef ECS örneklerinin PASSWD değerini kaydetmek için aşağıdaki komutu çalıştırın.

    PASSWD='yourpassword'
    Not

    Hedef ECS örneklerinin PASSWD değerleri farklıysa client.list dosyasını birden çok kez oluşturmanız ve 8. ile 10. adımları tekrar etmeniz gerekir.

  10. Yönetim düğümü için parola gerektirmeyen oturum açmayı yapılandırmak için aşağıdaki komutu çalıştırın.

    cat client.list | xargs -I {} ./auto_ssh.sh root $PASSWD {}
  11. client.list içinde kayıtlı olan ECS örneklerinde CPFS istemcisini uzaktan yüklemek için aşağıdaki komutu çalıştırın. Complete! döndürüldüğünde yükleme başarılı olur.

    region_id=`curl http://100.100.100.200/latest/meta-data/region-id`;
    wget https://cpfs-${region_id}-pre.oss-${region_id}-internal.aliyuncs.com/cpfs/CPFS2.3.4-CentOS.tar.gz -O /root/CPFS2.3.4-CentOS.tar.gz;
    cat client.list | xargs -I {} scp /root/CPFS2.3.4-CentOS.tar.gz {}:/root/
    pssh -ih client.list "tar xzvf /root/CPFS2.3.4-CentOS.tar.gz"
    pssh -ih client.list "cd /root/CPFS2.3.4-CentOS/CentOS7;yum install -y gpfs.adv-*.x86_64.rpm gpfs.base-*.x86_64.rpm gpfs.docs-*.noarch.rpm gpfs.gpl-*.noarch.rpm gpfs.gskit-*.x86_64.rpm gpfs.gss.pmsensors-*.x86_64.rpm gpfs.license.dm-*.x86_64.rpm gpfs.msg.en_US-*.noarch.rpm"
  12. client.list içinde kayıtlı olan ECS örneklerinde çekirdek uzantısını uzaktan derlemek için aşağıdaki komutu çalıştırın.

    pssh -ih client.list "/usr/bin/yum -y install cpp gcc-c++ elfutils-libelf-devel" 
    pssh -ih client.list "export LINUX_DISTRIBUTION=KERNEL_ORG_LINUX; /usr/lpp/mmfs/bin/mmbuildgpl"

    Bu yapılandırmayı ek ECS örneklerinde yeniden kullanmak için yapılandırılmış bir örnekten özel bir görüntü oluşturun. Özel görüntü oluşturma hakkında daha fazla bilgi için Özel görüntüler konusuna bakın.

Adım 3: Dosya sistemini bağlama

  1. Sol gezinme bölmesinde Instances seçeneğine tıklayın.

  2. Instance List sayfasında CPFS-POSIX istemci kurulum düğümü ECS örneğini (qr-001) bulun ve düğümde oturum açmak için İşlemler sütunundaki Connect öğesine tıklayın.

    Client Management Nodes bölümü, CPFS-POSIX istemci kurulum düğümü için oturum açma parolasını gösterir.

  3. Yönetim düğümündeki ve hedef ECS örneklerindeki hosts dosyasını güncellemek için aşağıdaki komutu çalıştırın.

    pssh -ih client.list "hostname;ifconfig eth0 | grep -v inet6 | grep inet | awk '{print \$2}'" | grep -v SUCC | sed 'N;s/\n/ /' > /tmp/ip-host-client.list
    pssh -ih qr.list "hostname;ifconfig eth0 | grep -v inet6 | grep inet | awk '{print \$2}'" | grep -v SUCC | sed 'N;s/\n/ /' > /tmp/ip-host-qr.list
    cat /tmp/ip-host-client.list | awk '{print $2,$1,$1"t_MAGICTAG"}' > /etc/client-hosts.append
    cat /tmp/ip-host-qr.list | awk '{print $2,$1,$1"t_MAGICTAG"}' > /etc/qr-hosts.append
    pssh -ih client.list "cp /etc/hosts hosts.bak"
    pssh -ih qr.list "cp /etc/hosts hosts.bak"
    cat client.list | xargs -I {} scp /etc/client-hosts.append {}:/etc/
    cat client.list | xargs -I {} scp /etc/qr-hosts.append {}:/etc/
    cat qr.list | xargs -I {} scp /etc/client-hosts.append {}:/etc/
    pssh -ih client.list "cat /etc/client-hosts.append >> /etc/hosts"
    pssh -ih client.list "cat /etc/qr-hosts.append >> /etc/hosts"
    pssh -ih qr.list "cat /etc/client-hosts.append >> /etc/hosts"
  4. Hedef ECS örneklerini CPFS kümesine eklemek için aşağıdaki komutu çalıştırın.

    1. Komut

      mmaddnode -N client.list
      mmchlicense client --accept -N client.list
      mmchnode --perfmon -N client.list
      mmstartup -N client.list
      mmgetstate -a
    2. Yanıt örneği

      Düğüm durumu active olarak değiştiğinde hedef ECS örneği CPFS kümesine başarıyla eklenmiş olur.

       Node number  Node name                            GPFS state  
      ---------------------------------------------------------------
                 1  cpfs-2989198****323d3-000001-qr-001  active
                 2  cpfs-2989198****323d3-000001-qr-002  active
                 3  cpfs-2989198****323d3-000001-qr-003  active
                 4  iZ0jl91t3p5kehvr6i5****              active
  5. Düğüm listesinin hedef ECS örneklerini içerdiğini doğrulamak için aşağıdaki komutu çalıştırın.

    • Komut

      mmlscluster
    • Yanıt örneği

       Node  Daemon node name                     IP address    Admin node name                      Designation
      -----------------------------------------------------------------------------------------------------------
         1   cpfs-2989198****323d3-000001-qr-001  192.168.3.57  cpfs-2989198****323d3-000001-qr-001  quorum-manager-perfmon
         2   cpfs-2989198****323d3-000001-qr-002  192.168.3.58  cpfs-2989198****323d3-000001-qr-002  quorum-manager-perfmon
         3   cpfs-2989198****323d3-000001-qr-003  192.168.3.56  cpfs-2989198****323d3-000001-qr-003  quorum-manager-perfmon
         4   iZ0jl91t3p5kehvr6i5****             192.168.3.59  iZ0jl91t3p5kehvr6i5****            perfmon
  6. (İsteğe bağlı) Varsayılan yolu sorgulayın.

    Hedef ECS örneğini CPFS-POSIX istemci yönetim düğümüne ekledikten sonra dosya sistemi /cpfs/<FSID seri numarası> varsayılan yoluna otomatik olarak bağlanır. Varsayılan bağlama yolunu görüntülemek için mmlsfs <FSID serial number>-<GENID> -T komutunu çalıştırın.

    • Komut örneği

      mmlsfs 2989198****323d3-000001 -T
    • Yanıt örneği

      flag                value                    description
      ------------------- ------------------------ -----------------------------------
       -T                 /cpfs/2989198****323d3-000001 Default mount point

    CPFS dosya sistemini özel bir yola bağlamak için mount --bind komutunu çalıştırın.

    mount --bind /cpfs/2989198****323d3-000001 /mnt/test

    Bu komutta */cpfs/2989198****323d3-000001, CPFS dosya sisteminin varsayılan bağlama yoludur ve /mnt/test* ise özel bağlama yoludur.

    Not
    • CPFS dosya sistemi kurulum düğümünde özel bağlama yollarına izin verilmez.

    • Alt dizin bağlama desteklenmez.

SSS

CPFS bağlama ile ilgili daha fazla SSS ve çözüm için Bağlama erişimi SSS konusuna bakın.

Referanslar